==> Kerapu-1.0.1.tar.gz: Kerapu-1.0.1/kerapu/boom/AttribuutGroep.py <==
"""
Kerapu
"""


class AttribuutGroep:
    """
    Klasse voor attribuutgroep.
    """

    # ------------------------------------------------------------------------------------------------------------------
    def __init__(self,
                 attribute_groep_id,
                 aantal_voorwaarden_voor_true,
                 koppelingen):
        """
        Object constructor.

        :param int attribute_groep_id: Het ID van deze attribuutgroep.
        :param int aantal_voorwaarden_voor_true: Het minimale aantal voorwaarden waaraan moet worden voldaan.
        :param list[kerapu.Boom.AttribuutGroepKoppeling.AttribuutGroepKoppeling.AttribuutGroepKoppeling] koppelingen: De
               attribuutgroepkoppelingen.
        """
        self._attribute_groep_id = attribute_groep_id
        """
        Het ID van deze attribuutgroep.

        :type: int
        """

        self._aantal_voorwaarden_voor_true = aantal_voorwaarden_voor_true
        """
        Het minimale aantal voorwaarden waaraan moet worden voldaan om deze attribuutgroep te laten vuren.

        :type: int
        """

        self._koppelingen = koppelingen
        """
        De attribuutgroepkoppelingen.

        :type: list[kerapu.Boom.AttribuutGroepKoppeling.AttribuutGroepKoppeling.AttribuutGroepKoppeling]
        """

    # ------------------------------------------------------------------------------------------------------------------
    def test(self, subtraject):
        """
        Test of een subtraject voldoet aan de voorwaarden van deze attribuutgroep.

        :param kerapu.Lbz.Subtraject.Subtraject subtraject: Het subtraject.

        :rtype: bool
        """
        aantal = 0
        for koppeling in self._koppelingen:
            if koppeling.test(subtraject):
                aantal += 1

        return aantal >= self._aantal_voorwaarden_voor_true

# ----------------------------------------------------------------------------------------------------------------------

==> Kerapu-2.0.1.tar.gz: Kerapu-2.0.1/kerapu/boom/AttribuutGroep.py <==
"""
Kerapu
"""
from kerapu.lbz.Subtraject import Subtraject


class AttribuutGroep:
    """
    Klasse voor attribuutgroep.
    """

    # ------------------------------------------------------------------------------------------------------------------
    def __init__(self,
                 attribute_groep_id: int,
                 aantal_voorwaarden_voor_true: int,
                 koppelingen: list):
        """
        Object constructor.

        :param int attribute_groep_id: Het ID van deze attribuutgroep.
        :param int aantal_voorwaarden_voor_true: Het minimale aantal voorwaarden waaraan moet worden voldaan.
        :param list[kerapu.boom.attribuut_groep_koppeling.AttribuutGroepKoppeling.AttribuutGroepKoppeling] koppelingen:
               De attribuutgroepkoppelingen.
        """
        self._attribute_groep_id = attribute_groep_id
        """
        Het ID van deze attribuutgroep.

        :type: int
        """

        self._aantal_voorwaarden_voor_true = aantal_voorwaarden_voor_true
        """
        Het minimale aantal voorwaarden waaraan moet worden voldaan om deze attribuutgroep te laten vuren.

        :type: int
        """

        self._koppelingen = koppelingen
        """
        De attribuutgroepkoppelingen.

        :type: list[kerapu.boom.attribuut_groep_koppeling..AttribuutGroepKoppeling.AttribuutGroepKoppeling]
        """

    # ------------------------------------------------------------------------------------------------------------------
    def test(self, subtraject: Subtraject) -> bool:
        """
        Test of een subtraject voldoet aan de voorwaarden van deze attribuutgroep.

        :param Subtraject subtraject: Het subtraject.

        :rtype: bool
        """
        aantal = 0
        for koppeling in self._koppelingen:
            if koppeling.test(subtraject):
                aantal += 1

        return aantal >= self._aantal_voorwaarden_voor_true

# ----------------------------------------------------------------------------------------------------------------------
